@@ -11,11 +11,11 @@ class StationBasedVehicle(Vehicle):
             "station": {
                 "title": "Origin station",
                 "description": "Origin station of the vehicle",
-                "type": "string"
+                "type": "string",
             }
         },
         "required": ["station"],
-        "remove_props": ["origin"]
+        "remove_props": ["origin"],
     }
 
     def __init__(self, simulation_model, agent_id, seats, station, **kwargs):
@@ -31,14 +31,13 @@ class StationBasedVehicle(Vehicle):
         # get the station agent
         station_agent = simulation_model.agentPopulation.get_agent(station)
         if station_agent is None:
-            raise ValueError("Could not match the station id '{}' with any simulation "
-                             "agent (initialising vehicle  {})".format(station, agent_id))
+            raise ValueError(
+                "Could not match the station id '{}' with any simulation "
+                "agent (initialising vehicle  {})".format(station, agent_id)
+            )
 
         # update the station's store
         station_agent.store.items.append(self)
         station_agent.initial_stock += 1
 
         super().__init__(simulation_model, agent_id, station_agent.origin, seats, **kwargs)
-
-
-
