@@ -2,7 +2,6 @@ from starling_sim.basemodel.input.dynamic_input import DynamicInput
 
 
 class Input(DynamicInput):
-
     def pre_process_input_dict(self, input_dict):
 
         # TODO : use a default fleet and stations name when there is no operator
@@ -21,7 +20,9 @@ class Input(DynamicInput):
                 input_dict["origin"] = user_station.position
 
             if "destination_station" in input_dict:
-                user_station = self.sim.agentPopulation["station"][input_dict["destination_station"]]
+                user_station = self.sim.agentPopulation["station"][
+                    input_dict["destination_station"]
+                ]
                 input_dict["destination"] = user_station.position
 
         elif input_dict["agent_type"] == "staff":
