@@ -6,15 +6,10 @@ class RepositioningStaff(RepositioningVehicle):
     This class describes the repositioning staff of the SB_VS_R model.
     """
 
-    SCHEMA = {
-        "properties": {},
-        "required": ["dwell_time"]
-    }
+    SCHEMA = {"properties": {}, "required": ["dwell_time"]}
 
-    def __init__(self, simulation_model, agent_id, origin,
-                 dwell_time, seats, **kwargs):
-        super().__init__(simulation_model, agent_id, origin, seats,
-                         dwell_time=dwell_time, **kwargs)
+    def __init__(self, simulation_model, agent_id, origin, dwell_time, seats, **kwargs):
+        super().__init__(simulation_model, agent_id, origin, seats, dwell_time=dwell_time, **kwargs)
 
     def loop_(self):
 
@@ -30,8 +25,13 @@ class RepositioningStaff(RepositioningVehicle):
             yield self.execute_process(self.move_())
 
             # wait for the fixed processing time
-            if next_stop.arrivalTime is not None and next_stop.arrivalTime > self.sim.scheduler.now():
-                yield self.execute_process(self.wait_(next_stop.arrivalTime - self.sim.scheduler.now()))
+            if (
+                next_stop.arrivalTime is not None
+                and next_stop.arrivalTime > self.sim.scheduler.now()
+            ):
+                yield self.execute_process(
+                    self.wait_(next_stop.arrivalTime - self.sim.scheduler.now())
+                )
 
             # process the stop
             yield self.execute_process(self.process_stop_(next_stop))
